@@ -177,7 +177,9 @@ extern "C" {
     pub fn fmpz_add_si(f: *mut fmpz, g: *const fmpz, x: mp_limb_signed_t);
     pub fn fmpz_sub_si(f: *mut fmpz, g: *const fmpz, x: mp_limb_signed_t);
     pub fn fmpz_addmul_ui(f: *mut fmpz, g: *const fmpz, x: mp_limb_t);
+    pub fn fmpz_addmul_si(f: *mut fmpz, g: *mut fmpz, x: mp_limb_signed_t);
     pub fn fmpz_submul_ui(f: *mut fmpz, g: *const fmpz, x: mp_limb_t);
+    pub fn fmpz_submul_si(f: *mut fmpz, g: *mut fmpz, x: mp_limb_signed_t);
     pub fn fmpz_addmul(f: *mut fmpz, g: *const fmpz, h: *const fmpz);
     pub fn fmpz_submul(f: *mut fmpz, g: *const fmpz, h: *const fmpz);
     pub fn fmpz_fmma(f: *mut fmpz, a: *const fmpz, b: *const fmpz, c: *const fmpz, d: *const fmpz);
@@ -206,7 +208,7 @@ extern "C" {
     pub fn fmpz_root(r: *mut fmpz, f: *const fmpz, n: mp_limb_signed_t);
     pub fn fmpz_is_perfect_power(root: *mut fmpz, f: *const fmpz) -> c_int;
     pub fn fmpz_sqrtrem(f: *mut fmpz, r: *const fmpz, g: *const fmpz);
-    pub fn fmpz_fdiv_ui(g: *mut fmpz, h: mp_limb_t) -> mp_limb_t;
+    pub fn fmpz_fdiv_ui(g: *const fmpz, h: mp_limb_t) -> mp_limb_t;
     pub fn fmpz_mod_ui(f: *mut fmpz, g: *const fmpz, h: mp_limb_t) -> mp_limb_t;
     pub fn fmpz_mod(f: *mut fmpz, g: *const fmpz, h: *const fmpz);
     pub fn fmpz_smod(f: *mut fmpz, g: *const fmpz, h: *const fmpz);
@@ -246,7 +248,7 @@ extern "C" {
     pub fn fmpz_cdiv_q_ui(f: *mut fmpz, g: *const fmpz, h: mp_limb_t);
     pub fn fmpz_cdiv_q_2exp(f: *mut fmpz, g: *const fmpz, exp: mp_limb_t);
     pub fn fmpz_cdiv_r_2exp(f: *mut fmpz, g: *const fmpz, exp: mp_limb_t);
-    pub fn fmpz_cdiv_ui(g: *mut fmpz, h: mp_limb_t) -> mp_limb_t;
+    pub fn fmpz_cdiv_ui(g: *const fmpz, h: mp_limb_t) -> mp_limb_t;
     pub fn fmpz_fdiv_qr(f: *mut fmpz, s: *mut fmpz, g: *const fmpz, h: *const fmpz);
     pub fn fmpz_fdiv_qr_preinvn(
         f: *mut fmpz,
