@@ -2,17 +2,15 @@
 
 //! *See the [FLINT documentation](http://flintlib.org/doc/fq_nmod_poly.html).
 
-
 use crate::deps::*;
 use crate::flint::*;
 use crate::fmpz::fmpz;
 use crate::fmpz_mod_poly::fmpz_mod_poly_struct;
-use crate::nmod_poly::nmod_poly_struct;
-use crate::fq_nmod::{fq_nmod_struct, fq_nmod_ctx_struct};
+use crate::fq_nmod::{fq_nmod_ctx_struct, fq_nmod_struct};
 use crate::fq_nmod_mat::fq_nmod_mat_struct;
+use crate::nmod_poly::nmod_poly_struct;
 use libc::{c_char, c_int, FILE};
 
-
 #[repr(C)]
 #[derive(Debug, Copy, Clone)]
 pub struct fq_nmod_poly_struct {
@@ -215,10 +213,8 @@ extern "C" {
         poly: *mut fq_nmod_poly_struct,
         ctx: *mut fq_nmod_ctx_struct,
     ) -> c_int;
-    pub fn fq_nmod_poly_is_one(
-        op: *mut fq_nmod_poly_struct,
-        ctx: *mut fq_nmod_ctx_struct,
-    ) -> c_int;
+    pub fn fq_nmod_poly_is_one(op: *mut fq_nmod_poly_struct, ctx: *mut fq_nmod_ctx_struct)
+        -> c_int;
     pub fn fq_nmod_poly_is_unit(
         op: *mut fq_nmod_poly_struct,
         ctx: *mut fq_nmod_ctx_struct,
