@@ -5,79 +5,79 @@
 pub mod deps;
 pub mod flint;
 
-pub mod perm;
 pub mod mpoly;
+pub mod perm;
 
-pub mod ulong_extras;
-pub mod fmpz;
-pub mod fmpz_vec;
-pub mod fmpz_factor;
-pub mod fmpz_mat;
-pub mod fmpz_lll;
-pub mod fmpz_poly;
-pub mod fmpz_poly_mat;
-pub mod fmpz_poly_factor;
-pub mod fmpz_mpoly;
-pub mod fmpz_mpoly_factor;
-pub mod long_extras;
 pub mod arith;
 pub mod fft;
+pub mod fmpz;
+pub mod fmpz_factor;
+pub mod fmpz_lll;
+pub mod fmpz_mat;
+pub mod fmpz_mpoly;
+pub mod fmpz_mpoly_factor;
+pub mod fmpz_poly;
+pub mod fmpz_poly_factor;
+pub mod fmpz_poly_mat;
+pub mod fmpz_vec;
+pub mod long_extras;
 pub mod qsieve;
+pub mod ulong_extras;
 
 pub mod fmpq;
-pub mod fmpq_vec;
 pub mod fmpq_mat;
-pub mod fmpq_poly;
 pub mod fmpq_mpoly;
 pub mod fmpq_mpoly_factor;
+pub mod fmpq_poly;
+pub mod fmpq_vec;
 pub mod fmpz_poly_q;
 
-pub mod n_poly;
-pub mod nmod_vec;
-pub mod nmod_mat;
-pub mod nmod_poly;
-pub mod nmod_poly_mat;
-pub mod nmod_poly_factor;
-pub mod nmod_mpoly;
-pub mod nmod_mpoly_factor;
 pub mod fmpz_mod;
-pub mod fmpz_mod_vec;
 pub mod fmpz_mod_mat;
-pub mod fmpz_mod_poly;
-pub mod fmpz_mod_poly_factor;
 pub mod fmpz_mod_mpoly;
 pub mod fmpz_mod_mpoly_factor;
+pub mod fmpz_mod_poly;
+pub mod fmpz_mod_poly_factor;
+pub mod fmpz_mod_vec;
+pub mod n_poly;
+pub mod nmod_mat;
+pub mod nmod_mpoly;
+pub mod nmod_mpoly_factor;
+pub mod nmod_poly;
+pub mod nmod_poly_factor;
+pub mod nmod_poly_mat;
+pub mod nmod_vec;
 
 pub mod fq;
-pub mod fq_vec;
-pub mod fq_mat;
-pub mod fq_poly;
-pub mod fq_poly_factor;
-pub mod fq_embed;
-pub mod fq_nmod;
-pub mod fq_nmod_vec;
-pub mod fq_nmod_mat;
-pub mod fq_nmod_poly;
-pub mod fq_nmod_poly_factor;
-pub mod fq_nmod_mpoly;
-pub mod fq_nmod_mpoly_factor;
-pub mod fq_nmod_embed;
-pub mod fq_zech;
-pub mod fq_zech_vec;
-pub mod fq_zech_mat;
-pub mod fq_zech_poly;
-pub mod fq_zech_poly_factor;
-pub mod fq_zech_mpoly;
-pub mod fq_zech_mpoly_factor;
-pub mod fq_zech_embed;
 pub mod fq_default;
 pub mod fq_default_mat;
 pub mod fq_default_poly;
 pub mod fq_default_poly_factor;
+pub mod fq_embed;
+pub mod fq_mat;
+pub mod fq_nmod;
+pub mod fq_nmod_embed;
+pub mod fq_nmod_mat;
+pub mod fq_nmod_mpoly;
+pub mod fq_nmod_mpoly_factor;
+pub mod fq_nmod_poly;
+pub mod fq_nmod_poly_factor;
+pub mod fq_nmod_vec;
+pub mod fq_poly;
+pub mod fq_poly_factor;
+pub mod fq_vec;
+pub mod fq_zech;
+pub mod fq_zech_embed;
+pub mod fq_zech_mat;
+pub mod fq_zech_mpoly;
+pub mod fq_zech_mpoly_factor;
+pub mod fq_zech_poly;
+pub mod fq_zech_poly_factor;
+pub mod fq_zech_vec;
 
 pub mod padic;
-pub mod padic_poly;
 pub mod padic_mat;
+pub mod padic_poly;
 pub mod qadic;
 
 #[cfg(test)]
@@ -85,11 +85,6 @@ mod tests {
     use super::*;
     use std::mem::MaybeUninit;
 
-    #[test]
-    fn it_works() {
-        assert_eq!(2 + 2, 4);
-    }
-
     #[test]
     fn try_it() {
         let mut p: fmpz::fmpz = fmpz::fmpz::default();
@@ -112,7 +107,6 @@ mod tests {
             fmpz_mod_poly::fmpz_mod_poly_clear(&mut f, &mut ctx);
             fmpz_mod::fmpz_mod_ctx_clear(&mut ctx);
             fmpz::fmpz_clear(&mut p);
-
         }
     }
 
